@@ -1,5 +1,6 @@
 from aguaclara.research.procoda_parser import *
-from aguaclara.core.units import unit_registry as u
+from aguaclara.core.units import u
+import aguaclara.core.utility as ut
 import pandas as pd
 import numpy as np
 from scipy import special
@@ -17,6 +18,7 @@ K_Henry_CO2 = 10**(-1.5) * u.mole/(u.L*u.atm)
 P_CO2 = 10**(-3.5) * u.atm
 
 
+@ut.list_handler()
 def invpH(pH):
     """Calculate inverse pH, i.e. hydronium ion concentration, given pH.
 
@@ -35,6 +37,7 @@ def invpH(pH):
     return 10**(-pH)*u.mol/u.L
 
 
+@ut.list_handler()
 def alpha0_carbonate(pH):
     """Calculate the fraction of total carbonates in carbonic acid form (H2CO3)
 
@@ -55,6 +58,7 @@ def alpha0_carbonate(pH):
     return alpha0_carbonate
 
 
+@ut.list_handler()
 def alpha1_carbonate(pH):
     """Calculate the fraction of total carbonates in bicarbonate form (HCO3-)
 
@@ -75,6 +79,7 @@ def alpha1_carbonate(pH):
     return alpha1_carbonate
 
 
+@ut.list_handler()
 def alpha2_carbonate(pH):
     """Calculate the fraction of total carbonates in carbonate form (CO3-2)
 
@@ -95,6 +100,7 @@ def alpha2_carbonate(pH):
     return alpha2_carbonate
 
 
+@ut.list_handler()
 def ANC_closed(pH, total_carbonates):
     """Calculate the acid neutralizing capacity (ANC) under a closed system
     in which no carbonates are exchanged with the atmosphere during the
@@ -111,7 +117,7 @@ def ANC_closed(pH, total_carbonates):
     :Examples:
 
     >>> from aguaclara.research.environmental_processes_analysis import ANC_closed
-    >>> from aguaclara.core.units import unit_registry as u
+    >>> from aguaclara.core.units import u
     >>> round(ANC_closed(10, 1*u.mol/u.L), 7)
     <Quantity(1.359831, 'equivalent / liter')>
     """
@@ -120,6 +126,7 @@ def ANC_closed(pH, total_carbonates):
             1 * u.eq/u.mol * Kw/invpH(pH) - 1 * u.eq/u.mol * invpH(pH))
 
 
+@ut.list_handler()
 def ANC_open(pH):
     """Calculate the acid neutralizing capacity (ANC) calculated under an open
     system based on pH.
@@ -179,6 +186,7 @@ def aeration_data(DO_column, dirpath):
     return aeration_results
 
 
+@ut.list_handler()
 def O2_sat(P_air, temp):
     """Calculate saturaed oxygen concentration in mg/L for 278 K < T < 318 K
 
@@ -193,7 +201,7 @@ def O2_sat(P_air, temp):
     :Examples:
 
     >>> from aguaclara.research.environmental_processes_analysis import O2_sat
-    >>> from aguaclara.core.units import unit_registry as u
+    >>> from aguaclara.core.units import u
     >>> round(O2_sat(1*u.atm , 300*u.kelvin), 7)
     <Quantity(8.0931572, 'milligram / liter')>
     """
@@ -220,7 +228,7 @@ def Gran(data_file_path):
     df = pd.read_csv(data_file_path, delimiter='\t', header=5)
     V_t = np.array(pd.to_numeric(df.iloc[0:, 0]))*u.mL
     pH = np.array(pd.to_numeric(df.iloc[0:, 1]))
-    df = pd.read_csv(data_file_path, delimiter='\t', header=-1, nrows=5)
+    df = pd.read_csv(data_file_path, delimiter='\t', header=None, nrows=5)
     V_S = pd.to_numeric(df.iloc[0, 1])*u.mL
     N_t = pd.to_numeric(df.iloc[1, 1])*u.mole/u.L
     V_eq = pd.to_numeric(df.iloc[2, 1])*u.mL
@@ -254,7 +262,7 @@ def CMFR(t, C_initial, C_influent):
     :Examples:
 
     >>> from aguaclara.research.environmental_processes_analysis import CMFR
-    >>> from aguaclara.core.units import unit_registry as u
+    >>> from aguaclara.core.units import u
     >>> round(CMFR(0.1, 0*u.mg/u.L, 10*u.mg/u.L), 7)
     <Quantity(0.9516258, 'milligram / liter')>
     >>> round(CMFR(0.9, 5*u.mg/u.L, 10*u.mg/u.L), 7)
@@ -331,7 +339,7 @@ def Tracer_CMFR_N(t_seconds, t_bar, C_bar, N):
     :Examples:
 
     >>> from aguaclara.research.environmental_processes_analysis import Tracer_CMFR_N
-    >>> from aguaclara.core.units import unit_registry as u
+    >>> from aguaclara.core.units import u
     >>> Tracer_CMFR_N([1, 2, 3, 4, 5]*u.s, 5*u.s, 10*u.mg/u.L, 3)
     <Quantity([2.96358283 6.50579498 8.03352597 7.83803116 6.72125423], 'milligram / liter')>
     """
@@ -391,7 +399,7 @@ def Tracer_AD_Pe(t_seconds, t_bar, C_bar, Pe):
     :Examples:
 
     >>> from aguaclara.research.environmental_processes_analysis import Tracer_AD_Pe
-    >>> from aguaclara.core.units import unit_registry as u
+    >>> from aguaclara.core.units import u
     >>> Tracer_AD_Pe([1, 2, 3, 4, 5]*u.s, 5*u.s, 10*u.mg/u.L, 5)
     <Quantity([0.25833732 3.23793989 5.8349833  6.62508831 6.30783131], 'milligram / liter')>
 
